(document:surround "/std/frame")

(define (update-mirror)
  (let ((mirror (form-value "mirror")))
    (form-update-visibility '("custom_url") (string=? mirror "custom"))
    (form-update-enum "repolist" (woo-list "/updates/avail_repo" 'mirror mirror))))

(define (update-mode)
  (let ((is-internet (string=? (or (form-value "mode") "") "internet"))
	(not-none  (not (string=? (or (form-value "mode") "") "none"))))
    (form-update-activity '("mirror"  "custom_url")
			  is-internet)
    (form-update-activity '("repolist" "schedule" "period" "weekday" "monthday" "time")
			  not-none)
    (and not-none (update-period))))

(define (update-period)
  (let ((period (or (form-value "period") "")))
    (form-update-activity '("monthday") (string=? period "monthly"))
    (form-update-activity '("weekday") (string=? period "weekly"))))

(define (ui-commit)
  (catch/message
    (lambda()
      (apply woo-write
	     "/updates"
	     (form-value-list)))))

(define (ui-init)
  (let ((data (woo-read-first "/updates")))
    (form-update-enum "mirror" (woo-list "/updates/avail_mirror"))
    (form-update-enum "weekday" (woo-list "/updates/avail_weekday"))
    (form-update-value-list '("mode" "mirror" "custom_url" "period" "weekday" "monthday" "time") data)
    (update-period)
    (update-mirror)
    (update-mode)
    (form-update-value-list '("repolist") data)))

(define stop (make-attribute 'stop))

(gridbox
  margin 30
  columns "0;100"
  (radio name "mode" value "none" colspan 2 text (_ "Don't update system"))
  (radio name "mode" value "local" colspan 2 text (_ "System update managed by server"))
  (radio name "mode" value "internet" colspan 2 text (_ "Update system automatically from Internet"))

  (label colspan 2)

  (label name "mirror" text (_ "Source:"))
  (combobox name "mirror")

  (spacer)
  (edit name "custom_url" visibility #t)

  (label colspan 2)

  (label name "repolist" text (_ "Repositories:") align "top")
  (checklistbox name "repolist")

  (label colspan 2)

  (label colspan 2 align "left" text (bold (_ "Update schedule")) name "schedule")
  (hbox
    colspan 2
    spacing 100
    ;;align "left"
    (gridbox
      columns "0;100"
      (radio name "period" value "daily" text (_ "Every day"))
      (spacer)

      (document:id bna (radio name "period" value "weekly" text (_ "Every week at:")))
      (combobox name "weekday" align "left")

      (radio name "period" value "monthly" text (_ "Every month at day:"))
      (spinbox align "left" minimum 1 maximum 31 step 1 name "monthday")

      (label colspan 2)

      (hbox colspan 2
       align "left"
       (label (_ "Time:") name "time")
        (timeedit name "time" stop #t))))

  (label colspan 2)

  (hbox
    align "left"
    (button name "apply" text (_ "Apply"))
    (button name "reset" text (_ "Reset"))))


(document:root
  (when loaded
     (ui-init)
    (form-bind "mirror" "change" update-mirror)
    (form-bind "mode" "change" update-mode)
    (form-bind "period" "change" update-period)
    (form-bind "apply" "click" ui-commit)
    (form-bind "reset" "click" ui-init)))
